@@ -75,9 +75,15 @@ char * move_to_ascii(char *p, int from, int to)
 {
   int a;
 
-  *p++   = from - from / 10 * 10 + 96;   /*  a - h       */
-  *p++   = from / 10 + 47 ;              /*  1 - 8       */
-  //  *p++   = '-'; 
+  if (from)
+    {
+      *p++   = from - from / 10 * 10 + 96;   /*  a - h       */
+      *p++   = from / 10 + 47 ;              /*  1 - 8       */
+    }
+  else // bughouse 
+    {
+      *p++ = '@';
+    }
 
   if (to & 128) 
     {       // promotion
@@ -164,6 +170,18 @@ void ascii_to_move(char *p, int *from, int *to)
       *from = (*p - 'a' + 1) + (*(p+1) - '1' + 2 ) * 10;
       p+=2;
       *to   = (*p - 'a' + 1) + (*(p+1) - '1' + 2 ) * 10;
+
+      /* sanity checks */
+      if (*from < A1 || *from > H8) 
+	{
+	  debug_print(DEBUG_NORMAL,"move_to_asii: illegal from: %d\n",*from);
+	  *from = 0;
+	}
+      if (*to   < A1 || *to > H8 )
+	{
+	  debug_print(DEBUG_NORMAL,"move_to_asii: illegal to: %d\n",*to);
+	  *to = 0;
+	}
     }
 }
 
@@ -227,6 +245,8 @@ char * move_to_san(position *pos, int from, int to) {
 		piece = pos->square[to];
 	}
 
+	if (from)
+	  {
 	/* Check if we have to designate the rank or file */
 	switch (piece) {
 		case WQ:
@@ -340,6 +360,7 @@ char * move_to_san(position *pos, int from, int to) {
 			break;				
 
 	}
+	  } // ! from
 
 	/* Handle Castling */
 	if ((piece == WK || piece == BK) && abs(from-to) == 2) {
@@ -353,11 +374,18 @@ char * move_to_san(position *pos, int from, int to) {
 		if (norm > 0)
 		        *temp++ = piece_to_ascii[norm];
 
-		/* The rank/file designators */
-		if (desfile)
-			file_to_ascii(&temp, from);
-		if (desrank)
-			rank_to_ascii(&temp, from);
+		if (from == 0)
+		  {
+		    *temp++ = '@';
+		  }
+		else
+		  {
+		    /* The rank/file designators */
+		    if (desfile)
+		      file_to_ascii(&temp, from);
+		    if (desrank)
+		      rank_to_ascii(&temp, from);
+		  }
 
 		/* If there was a capture */
 		if (pos->vf != EMPTY) {
