@@ -24,7 +24,6 @@
 
 #include "makros.h"
 #include "zvt.h"
-#include "portab.h"
 #include "child.h"
 #include "cho1.h"
 #include "pro.h"
@@ -58,7 +57,7 @@ struct engine * engine_local_new(char *cmd, char *arg) {
 	e = engine_new(cmd, argv);
 	engine_local_menu_init(e);
 
-	gdk_input_add( fileno(e->read_from), GDK_INPUT_READ, engine_local_cb, e);
+	e->input_callback = gdk_input_add( fileno(e->read_from), GDK_INPUT_READ, engine_local_cb, e);
 
 	engine_write(e,"xboard\n");
 	engine_write(e,"post\n");
@@ -92,18 +91,16 @@ static void engine_local_menu_init(struct engine *e) {
 	check_menu(MENU_CBLACK);
 }
 
-static void engine_local_move(char *p)
-{
-	    int from,to,piece;
+static void engine_local_move(char *p) {
+	int from,to,piece;
 
-	    ascii_to_move(p,&from,&to);
-	    if (debug)
-	      printf("move detected: %s %d %d\n",p+4,from,to);
-	    piece= currPositionPtr->square[from];
-	    gnomechess_position_make_move(currPositionPtr,from,to);
-	    gnomechess_sound_enginemove();
-	    gnomechess_movelist_add(board.movelist, piece,from,to);
-	    gnomechess_board_update();
+	ascii_to_move(p,&from,&to);
+	debug_print(DEBUG_NORMAL,"Move detected: %s %d %d\n",p+4,from,to);
+	piece= currPositionPtr->square[from];
+	gnomechess_position_move(currPositionPtr,from,to);
+	gnomechess_sound_enginemove();
+	gnomechess_movelist_add(board.movelist, piece,from,to);
+	gnomechess_board_update();
 }
 
 static void
@@ -183,7 +180,7 @@ static void engine_local_cwhite_cb (GtkWidget *widget, void *data) {
 
 	engine_write(first_chess_programm,"white\n");
 
-	if (currPositionPtr->tomove == WMOVE)
+	if (currPositionPtr->tomove == WHITE)
 		engine_write(first_chess_programm,"go\n");
 
 	gnomechess_board_set_flip(TRUE);
@@ -194,7 +191,7 @@ static void engine_local_cblack_cb (GtkWidget *widget, void *data) {
 
 	engine_write(first_chess_programm,"black\n");
 
-	if (currPositionPtr->tomove == BMOVE)
+	if (currPositionPtr->tomove == BLACK)
 		engine_write(first_chess_programm,"go\n");
 
 	gnomechess_board_set_flip(FALSE);
@@ -208,8 +205,19 @@ void engine_local_cb( gpointer data, gint source, GdkInputCondition condition)
 
   char *p,*q;
   ssize_t len;
+  struct engine *e;
 
   len = read(source, b, sizeof buf - 1 - (b-buf));
+  e = (struct engine *) data;
+
+  if (len == 0) /* engine died */
+    {
+      gdk_input_remove(e->input_callback);
+      //  engine_destroy(data);
+      //abort();
+      return;
+    }
+
   if (len > 0) 
     {
       b[len] = 0;
@@ -225,8 +233,7 @@ void engine_local_cb( gpointer data, gint source, GdkInputCondition condition)
       tmp = *(q+1);
       *(q+1) = 0;
 
-      if (debug)
-       fputs(buf,stderr);
+      debug_print(DEBUG_VERBOSE,buf);
 
       zvt_print_raw_text(board.messages, buf);
 
