@@ -27,7 +27,6 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include "portab.h"
 #include "makros.h"
 #include "position.h"
 #include "pro.h"
@@ -611,22 +610,22 @@ static void delete_equal(char *str)
 	p++;
 }
 
-static inline int txt_reg_move_found(BYTE *aq, int test)
+static inline int txt_reg_move_found(gchar *aq, int test)
 {
 	    int piece=currPositionPtr->square[*aq];
-	    gnomechess_position_make_move(currPositionPtr,*aq,*(aq+1));
+	    gnomechess_position_move(currPositionPtr,*aq,*(aq+1));
 	    if (!test) gnomechess_movelist_add(board.movelist, piece,*aq,*(aq+1));
 	    return TRUE;		
 }
 
 static int txt_reg_move(char *str, int test)
 {
-  WORD anz,anz_n,anz_s;
-  WORD i;
-  BYTE *ap,*aq;
-  BYTE *p;
-  BYTE zugliste[AB_ZUGL];
-  BYTE liste[100][10];
+  gshort anz,anz_n,anz_s;
+  gshort i;
+  gchar *ap,*aq;
+  gchar *p;
+  gchar zugliste[AB_ZUGL];
+  gchar liste[100][10];
 
   delete_x(str);
   delete_plus(str);
@@ -639,7 +638,7 @@ static int txt_reg_move(char *str, int test)
   for ( aq = ap , i = 0 ; i < anz ; i++ , aq += 2 ) 
   {
     p=liste[i];
-    piece_move_to_ascii(p,currPositionPtr->square[(WORD)*aq],*aq,*(aq+1));
+    piece_move_to_ascii(p,currPositionPtr->square[(gshort)*aq],*aq,*(aq+1));
     if ( *p == ' ')  /* pawn move */
       {
 	p++;         /* e.g. e2e4 */
